==> digikam-6.1.0.tar.xz: digikam-6.1.0/core/dplugins/bqm/enhance/noisereduction/noisereduction.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2009-11-21
 * Description : Wavelets Noise Reduction batch tool.
 *
 * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BQM_NOISE_REDUCTION_H
#define DIGIKAM_BQM_NOISE_REDUCTION_H

// Local includes

#include "batchtool.h"
#include "nrsettings.h"

using namespace Digikam;

namespace DigikamBqmNoiseReductionPlugin
{

class NoiseReduction : public BatchTool
{
    Q_OBJECT

public:

    explicit NoiseReduction(QObject* const parent = 0);
    ~NoiseReduction();

    BatchToolSettings defaultSettings();

    BatchTool* clone(QObject* const parent=0) const { return new NoiseReduction(parent); };

    void registerSettingsWidget();

private:

    bool toolOperations();

private Q_SLOTS:

    void slotAssignSettings2Widget();
    void slotSettingsChanged();

private:

    NRSettings* m_settingsView;
};

} // namespace DigikamBqmNoiseReductionPlugin

#endif // DIGIKAM_BQM_NOISE_REDUCTION_H

==> digikam_6.4.0+dfsg.orig.tar.xz: digikam-6.4.0+dfsg/core/dplugins/bqm/enhance/noisereduction/noisereduction.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2009-11-21
 * Description : Wavelets Noise Reduction batch tool.
 *
 * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BQM_NOISE_REDUCTION_H
#define DIGIKAM_BQM_NOISE_REDUCTION_H

// Local includes

#include "batchtool.h"
#include "nrsettings.h"

using namespace Digikam;

namespace DigikamBqmNoiseReductionPlugin
{

class NoiseReduction : public BatchTool
{
    Q_OBJECT

public:

    explicit NoiseReduction(QObject* const parent = nullptr);
    ~NoiseReduction();

    BatchToolSettings defaultSettings();

    BatchTool* clone(QObject* const parent=nullptr) const { return new NoiseReduction(parent); };

    void registerSettingsWidget();

private:

    bool toolOperations();

private Q_SLOTS:

    void slotAssignSettings2Widget();
    void slotSettingsChanged();

private:

    NRSettings* m_settingsView;
};

} // namespace DigikamBqmNoiseReductionPlugin

#endif // DIGIKAM_BQM_NOISE_REDUCTION_H
